library(lavaan)

################################################################################
## data preparation
################################################################################

mymeans <- scan("posaff.items.823.dat", skip=0, nlines=1)
mysd <- scan("posaff.items.823.dat", skip=1, nlines=1)
mycors <- scan("posaff.items.823.dat", skip=2)

xindex <- c(0, 1, 3, 6, 10, 15)
posaff <- outer(1:6, 1:6, FUN = function(X, Y) ifelse(Y <= X, mycors[Y + xindex[X]], 0))

mynames <- c("Glad1", "Cheer1", "Happy1", "Glad2", "Cheer2", "Happy2")
colnames(posaff) <- mynames
rownames(posaff) <- mynames

myvarcov <- outer(mysd, mysd, FUN="*")
mycov <- posaff * myvarcov

nob <- 823

################################################################################
##  Longitudinal CFA
################################################################################

Lmod1 <- 'Positive1  =~ L1*Glad1 + L2*Cheer1 + L3*Happy1
				  Positive2  =~ L4*Glad2 + L5*Cheer2 + L6*Happy2

			    Positive1 ~~ Positive2

          Positive1 ~~ Positive1
          Positive2 ~~ Positive2

          Glad1 ~~ Glad2
          Cheer1 ~~ Cheer2
          Happy1 ~~ Happy2

          Glad1 ~~ Glad1
          Cheer1 ~~ Cheer1
          Happy1 ~~ Happy1

          Glad2 ~~ Glad2
          Cheer2 ~~ Cheer2
          Happy2 ~~ Happy2

          Glad1 ~ t1*1                
          Cheer1 ~ t2*1
          Happy1 ~ t3*1
          Glad2 ~ t4*1
          Cheer2 ~ t5*1
          Happy2 ~ t6*1

          Positive1 ~ 1
          Positive2 ~ 1

          t1 == 0 - t2 - t3
          t4 == 0 - t5 - t6

          L1 == 3 - L2 - L3
          L4 == 3 - L5 - L6'

fit1 <- lavaan(Lmod1, sample.cov=mycov, meanstructure=T, sample.nobs = nob, sample.mean=mymeans)#, std.lv=F, auto.fix.first=F)

summary(fit1, standardized=T, fit.measures=T)